# Changelog

## [0.2.2](https://github.com/charmarr/charmarr-lib/compare/charmarr-lib-vpn-v0.2.1...charmarr-lib-vpn-v0.2.2) (2025-12-16)


### Bug Fixes

* **vpn:** fixes local version file update ([c4b5ce2](https://github.com/charmarr/charmarr-lib/commit/c4b5ce27825522ff07aee1e194755ced42401f8c))

## [0.2.1](https://github.com/charmarr/charmarr-lib/compare/charmarr-lib-vpn-v0.2.0...charmarr-lib-vpn-v0.2.1) (2025-12-16)


### Bug Fixes

* **vpn:** fixes release please process ([72c0ea3](https://github.com/charmarr/charmarr-lib/commit/72c0ea3998188b96b74445e7076ac9e0ac5cebd2))

## [0.2.0](https://github.com/charmarr/charmarr-lib/compare/charmarr-lib-vpn-v0.1.0...charmarr-lib-vpn-v0.2.0) (2025-12-15)


### Features

* adds dev envs for charmarr lib packages ([b8ee5b2](https://github.com/charmarr/charmarr-lib/commit/b8ee5b29bf07a9c4e53a5443da3742c62ec4191c))
* scaffolds monorepo with required packages ([eca8d38](https://github.com/charmarr/charmarr-lib/commit/eca8d38bec8f03dcabd4363b84e1743e495fed4c))
